@@ -2,22 +2,22 @@
 Data for colorblind friendly colormaps.
 
 """
-import numpy as np
 import os
 
+import numpy as np
+
 
 def yuv_rainbow_24(nc):
     path1 = np.linspace(0.8 * np.pi, 1.8 * np.pi, nc)
     path2 = np.linspace(-0.33 * np.pi, 0.33 * np.pi, nc)
 
-    y = np.concatenate([np.linspace(0.3, 0.85, nc * 2 // 5),
-                        np.linspace(0.9, 0.0, nc - nc * 2 // 5)])
+    y = np.concatenate(
+        [np.linspace(0.3, 0.85, nc * 2 // 5), np.linspace(0.9, 0.0, nc - nc * 2 // 5)]
+    )
     u = 0.40 * np.sin(path1)
     v = 0.55 * np.sin(path2) + 0.1
 
-    rgb_from_yuv = np.array([[1, 0, 1.13983],
-                             [1, -0.39465, -0.58060],
-                             [1, 2.03211, 0]])
+    rgb_from_yuv = np.array([[1, 0, 1.13983], [1, -0.39465, -0.58060], [1, 2.03211, 0]])
     cmap_dict = {'blue': [], 'green': [], 'red': []}
     for i in range(len(y)):
         yuv = np.array([y[i], u[i], v[i]])
