@@ -15,6 +15,8 @@ from .sample_files import (
     EXAMPLE_DLPPI,
     EXAMPLE_EBBR1,
     EXAMPLE_EBBR2,
+    EXAMPLE_HK,
+    EXAMPLE_INI,
     EXAMPLE_IRTSST,
     EXAMPLE_LCL1,
     EXAMPLE_MET1,
@@ -23,22 +25,21 @@ from .sample_files import (
     EXAMPLE_MET_TEST1,
     EXAMPLE_MET_TEST2,
     EXAMPLE_MET_WILDCARD,
+    EXAMPLE_MET_YAML,
     EXAMPLE_METE40,
     EXAMPLE_MFRSR,
     EXAMPLE_MPL_1SAMPLE,
     EXAMPLE_NAV,
     EXAMPLE_NOAA_PSL,
+    EXAMPLE_NOAA_PSL_TEMPERATURE,
     EXAMPLE_RL1,
     EXAMPLE_SIGMA_MPLV5,
     EXAMPLE_SIRS,
     EXAMPLE_SONDE1,
     EXAMPLE_SONDE_WILDCARD,
+    EXAMPLE_SP2B,
     EXAMPLE_STAMP_WILDCARD,
     EXAMPLE_SURFSPECALB1MLAWER,
     EXAMPLE_TWP_SONDE_20060121,
     EXAMPLE_IRT25m20s,
-    EXAMPLE_HK,
-    EXAMPLE_INI,
-    EXAMPLE_SP2B,
-    EXAMPLE_MET_YAML
 )
